=============================
Ivy workflow engine
=============================

.. image:: https://travis-ci.org/cosmo-ethz/CosmoHammer.png?branch=master
        :target: https://travis-ci.org/cosmo-ethz/CosmoHammer
        
.. image:: https://coveralls.io/repos/cosmo-ethz/CosmoHammer/badge.svg
  		:target: https://coveralls.io/r/cosmo-ethz/CosmoHammer

Simple and flexible workflow engine


Features
--------

* Helps to design and execute workflows
* Clear and flexible API
* Supports very simple to arbitrarily complex workflows
